# -*- encoding: utf-8 -*-

from django.db import models


class NoDeleteQuerySet(models.query.QuerySet):
    """
    Pas de delete, flag à supprimer sur les entrées.
    """
    def delete(self):
        self.update(supprime=True)


class NoDeleteManager(models.Manager):
    """
    Les entrées supprimées sont exclues des querysets.
    """
    def get_query_set(self):
        return NoDeleteQuerySet(self.model, using=self._db).filter(supprime=False)


class ActifsManager(NoDeleteManager):
    """
    Seulement les entrées actives
    """
    def get_query_set(self):
        return super(ActifsManager, self).get_query_set().filter(actif=True)


class InactifsManager(NoDeleteManager):
    """
    Seulement les entrées inactives
    """
    def get_query_set(self):
        return super(InactifsManager, self).get_query_set().filter(actif=False)
